import sys
from os import environ
from os.path import abspath, dirname
__lib = '%s/lib'%abspath(dirname(__file__))
if not __lib in sys.path:
	sys.path.append(__lib)

from pwclip.clipper import clipgui

def pwclipper():
    mode = 'yk'
    if [a for a in sys.argv if a == '-c']:
        del sys.argv[sys.argv.index('-c')]
        mode = 'pc'
    wait = 3
    if len(sys.argv) > 1:
        wait = int(sys.argv[1])
    elif 'PWCLIPTIME' in environ.keys():
        wait = int(environ['PWCLIPTIME'])
    clipgui(mode, wait)




"""pwclip packaging information"""
import sys
from os import getcwd
from os.path import join, dirname

modname = distname = 'pwclip'
numversion = (0, 3, 2)
version = '.'.join([str(num) for num in numversion])
install_requires = ['pyusb', 'yubico', 'tkinter', 'gnupg']
if sys.version_info[:2] > (2, 7):
	install_requires = ['pyusb', 'yubico', 'gnupg']
license = 'GPL'
description = "gui to temporarily save passwords to clipboard (paste-buffer)"
web = 'http://janeiskla.de'
mailinglist = ""
author = 'Leon Pelzer'
author_email = 'mail@leonpelzer.de'
classifiers = ['Development Status :: 4 - Beta',
               'Environment :: Console',
               'Environment :: MacOS X',
               'Environment :: Win32 (MS Windows)',
               'Environment :: X11 Applications',
               'Intended Audience :: Developers',
               'Intended Audience :: End Users/Desktop',
               'Intended Audience :: System Administrators',
               'Intended Audience :: Information Technology',
               'License :: OSI Approved :: GNU General Public License (GPL)',
               'Operating System :: OS Independent',
               'Programming Language :: Python',
               'Programming Language :: Python :: 3',
               'Topic :: Security',
               'Topic :: Utilities',
               'Topic :: Desktop Environment',
               'Topic :: System :: Systems Administration']

with open(join(getcwd(), 'README'), 'r') as rfh:
	readme = rfh.read()

long_desc = ( readme )

scripts = [join('bin', 'pwclip')]

entry_points = {'console_scripts': ['pwclip = pwclip.__init__:pwclipper']}



#!/usr/bin/env python3
# -*- encoding: utf-8 -*-
#
# This file is free software by d0n <d0n@janeiskla.de>
#
# You can redistribute it and/or modify it under the terms of the GNU -
# Lesser General Public License as published by the Free Software Foundation
#
# This is distributed in the hope that it will be useful somehow.
#
# !WITHOUT ANY WARRANTY!
#
# Without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
# details.
#
"""
yubikey challenge-response lib
"""

from binascii import hexlify

from yubico import \
    find_yubikey, yubikey, \
    yubico_exception

def yubikeys(ykser=None, dbg=None):
	"""
	return a list of yubikeys objects
	"""
	keys = {}
	for i in range(0, 255):
		try:
			key = find_yubikey(debug=dbg, skip=i)
		except yubikey.YubiKeyError:
			break
		if ykser and int(ykser) != int(key.serial()):
			continue
		keys[key.serial()] = key
	return keys

def ykslotchalres(yk, chal, slot):
	"""
	challenge-response function using with given
	challenge (chal) for slot on yubikey found by yubikeys()
	"""
	try:
		return hexlify(yk.challenge_response(
			chal.ljust(64, '\0').encode(), slot=slot)).decode()
	except yubico_exception.YubicoError:
		pass

def ykchalres(chal, slot=2, ykser=None):
	"""
	challenge-response function using specified slot
	or default (2) as wrapping function for yubikeys() and slotchalres()
	"""
	keys = yubikeys(ykser)
	for (_, key) in keys.items():
		return ykslotchalres(key, chal, slot)




#!/usr/bin/env python3

import sys
from os import getcwd

try:
	import pwclip
except ImportError:
	sys.path.append(getcwd())
	import pwclip

try:
	pwclip.pwclipper()
except KeyboardInterrupt:
	print('\naborted by keystroke')
	exit(0)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""Generic Setup script, takes package info from __pkginfo__.py file.
"""
from sys import argv
from os import listdir, chdir, getcwd, path
from setuptools import setup

__docformat__ = "restructuredtext en"

def packages(directory):
    """return a list of subpackages for the given directory"""
    result = []
    for package in listdir(directory):
        absfile = path.join(directory, package, '__init__.py')
        if path.exists(absfile):
            result.append(path.dirname(absfile))
            result += packages(path.dirname(absfile))
    return result

def scripts(linux_scripts):
    """creates the proper script names required for each platform"""
    from distutils import util
    if util.get_platform()[:3] == 'win':
        return linux_scripts + [script + '.bat' for script in linux_scripts]
    return linux_scripts

def setupkwargs(pinf):
    """translate default __pkginfo__ keywords
    to those understood by setuptools.setup"""
    skwargs = {}
    uniss = (
        'author',
        'license',
        'version',
        'data_files',
        'description',
        'ext_modules',
        'author_email',
        'install_requires')
    unils = (
        'packages',
        'classifiers',
        'entry_points',
        'include_dirs',
        'dependency_links')
    names = {
        'web': 'url',
        'modname': 'name',
        'distname': 'name',
        'long_desc': 'long_description'}
    for uni in uniss:
        skwargs[uni] = pinf.get(uni, None)
    for uni in unils:
        skwargs[uni] = pinf.get(uni, [])
    for (key, val) in names.items():
        if key in pinf:
            skwargs[val] = pinf[key]
            if key in skwargs.keys():
                del skwargs[key]
    return skwargs


if __name__ == '__main__':
    __pkginfo__ = {}
    __pkginfo__['packages'] = ['pwclip'] + packages('pwclip')
    with open(path.join('pwclip', '__pkginfo__.py')) as f:
        exec(f.read(), __pkginfo__)
    kwargs = setupkwargs(__pkginfo__)
    if '-v' in argv or '--verbose' in argv:
        print()
        for (k, v) in sorted(kwargs.items()):
            print(k, '=', v)
        print()
    print(kwargs)
    setup(**kwargs)



#!/usr/bin/env python3

from os import path, uname, remove, environ

from tarfile import open as taropen

from yaml import load, dump

from time import sleep

from tempfile import NamedTemporaryFile

from colortext import tabd, error, fatal

from system import userfind

from cypher import GPGTool, ykchalres

class PassCrypt(GPGTool):
	dbg = False
	user = userfind()
	home = userfind(user, 'home')
	plain = '%s/.pwd.yaml'%home
	crypt = '%s/.passcrypt'%home
	def __init__(self, *args, **kwargs):
		for arg in args:
			if hasattr(self, arg):
				setattr(self, arg, True)
		for (key, val) in kwargs.items():
			if hasattr(self, key):
				setattr(self, key, val)
		self._mergeplain_()
		if self.dbg:
			lim = int(max(len(k) for k in PassCrypt.__dict__.keys()))+4
			print('%s\n%s\n\n%s\n%s\n'%(
                PassCrypt.__mro__,
                '\n'.join('  %s%s=    %s'%(
                    k, ' '*int(lim-len(k)), v
                ) for (k, v) in sorted(PassCrypt.__dict__.items())),
                PassCrypt.__init__,
                '\n'.join('  %s%s=    %s'%(k[1:], ' '*int(lim-len(k)), v
                    ) for (k, v) in sorted(self.__dict__.items()))))

	def _mergeplain_(self):
		__pws = self._readcrypt()
		if not __pws:
			__pws = {self.user:[{}]}
		if path.exists(self.plain):
			try:
				with open(self.plain, 'r') as pfh:
					__newpws = load(pfh.read())
				#remove(self.plain)
			except FileNotFoundError:
				__newpws = {}
			for (k, v) in __newpws.items():
				__pws[k] = v
			self._writecrypt_(__pws)

	def _readcrypt(self):
		if self.dbg:
			print('%s\n  crypt = %s'%(self._readcrypt, self.crypt))
		if path.exists(self.crypt):
			with open(self.crypt, 'r') as vlt:
				crypt = vlt.read()
			return load(str(self.decrypt(crypt)))

	def _writecrypt_(self, plain):
		if self.dbg:
			print('%s\n  weaknez = %s'%(self._writecrypt, plain))
		kwargs = {'output': self.crypt}
		if 'GPGKEYS' in environ.keys():
			kwargs['recipients'] = environ['GPGKEYS'].split(' ')
		self.encrypt(message=dump(plain), **kwargs)

	def adpw(self, usr, pwd=None):
		pwdcom = [pwd if pwd else self._passwd()]
		com = input('enter a comment: ')
		if com:
			pwdcom.append(com)
		if self.dbg:
			print('%s\n adduser = %s addpass = %s'%(
                self.adpw, usr, pwd))
		__weak = self._readcrypt()
		if __weak and self.user in __weak.keys():
			__weak[self.user][usr] = pwdcom
			self._writecrypt_(__weak)
			return True

	def chpw(self, usr, pwd=None):
		pwd = pwd if pwd else self._passwd()
		if self.dbg:
			print('%s\n adduser = %s addpass = %s'%(
                self.chpw, usr, pwd))
		__weak = self._readcrypt()
		if __weak and self.user in __weak.keys() and \
              usr in __weak[self.user].keys():
			__weak[self.user][usr] = pwd
			self._writecrypt_(__weak)
			return True

	def rmpw(self, usr):
		if self.dbg:
			print('%s\n  user = %s\n  deluser = %s'%(
                self.rmpw, self.user, usr))
		__weak = self._readcrypt()
		if __weak and self.user in __weak.keys() and \
              usr in __weak[self.user].keys():
			del __weak[self.user][usr]
			self._writecrypt_(__weak)
			return True

	def lspw(self, usr=None, crypt=None):
		if self.dbg:
			print('%s\n  user = %s\n  getuser = %s'%(
                self.lspw, self.user, usr))
		__weaks = self._readcrypt()
		if path.exists(self.crypt) and not __weaks:
			__weaks = self._readcrypt()
		if __weaks:
			if self.user in __weaks.keys():
				__weaks = __weaks[self.user]
			if not usr:
				return __weaks
			for (u, p) in __weaks.items():
				if usr == u:
					return p

def passcrypt(usr):
	if usr:
		__entry = PassCrypt().lspw(usr)
		if __entry:
			return __entry[0]

if __name__ == '__main__':
    exit(1)
